@@ -1,9 +1,13 @@
-from snek5000 import mpi
 from snek5000.output.base import Output as OutputBase
+
 from snek5000_cbox.templates import box, size, makefile_usr
 
 
 class OutputCbox(OutputBase):
+    template_box = box
+    template_makefile_usr = makefile_usr
+    template_size = size
+
     @property
     def makefile_usr_sources(self):
         """
@@ -31,15 +35,5 @@ class OutputCbox(OutputBase):
             ],
         }
 
-    def post_init(self):
-        super().post_init()
-
-        # Write additional source files to compile the simulation
-        if mpi.rank == 0 and self._has_to_save and self.sim.params.NEW_DIR_RESULTS:
-            self.write_box(box)
-            self.write_size(size)
-            self.write_makefile_usr(makefile_usr)
-            print(f"{makefile_usr = }")
-
 
 Output = OutputCbox
